Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/ht16k33_matrix_simpletest.py
    :caption: examples/ht16k33_matrix_simpletest.py
    :linenos:

.. literalinclude:: ../examples/ht16k33_segments_simpletest.py
    :caption: examples/ht16k33_segments_simpletest.py
    :linenos:

.. literalinclude:: ../examples/ht16k33_bicolor24_simpletest.py
    :caption: examples/ht16k33_bicolor24_simpletest.py
    :linenos:

.. literalinclude:: ../examples/ht16k33_matrix_pillow_image.py
    :caption: examples/ht16k33_matrix_pillow_image.py
    :linenos:

.. literalinclude:: ../examples/ht16k33_animation_demo.py
    :caption: examples/ht16k33_animation_demo.py
    :linenos:
